BradfordLms

Type Alias BradfordLms 

pub type BradfordLms<M, T> = Lms<WithLmsMatrix<M, Bradford>, T>;
LMS that uses the Bradford matrix.

Aliased Type

#[repr(C)]
pub struct BradfordLms<M, T> { pub long: T, pub medium: T, pub short: T, pub meta: PhantomData<WithLmsMatrix<M, Bradford>>, }

Fields

long: T

Stimulus from long wavelengths, or red, or ρ. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.

medium: T

Stimulus from medium wavelengths, or green, or γ. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.

short: T

Stimulus from short wavelengths, or blue, or β. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.

meta: PhantomData<WithLmsMatrix<M, Bradford>>

Type level meta information, such as reference white, or which matrix was used when converting from XYZ.