#[repr(C)]pub struct Lms<M, T> {
pub long: T,
pub medium: T,
pub short: T,
pub meta: PhantomData<M>,
}Expand description
Generic LMS.
LMS represents the response of the eye’s cone cells. L, M and S are for
“long”, “medium” and “short” wavelengths, roughly corresponding to red,
green and blue. Many newer mentions of an LMS representation use the letters
R, G and B instead (or sometimes ρ, γ, β), but this library sticks to LMS to
differentiate it from Rgb.
The LMS color space is a model of the physiological response to color
stimuli. It has some mathematical shortcomings that Xyz improves on,
such as severe spectral sensitivity overlap between L, M and S. Despite
this, LMS has a lot of uses, include chromatic adaptation and emulating
different types of color vision deficiency, and it’s sometimes part of the
conversion process between other color spaces.
Creating a Value
An LMS value is often derived from another color space, through a conversion
matrix. Two such matrices are VonKries and
Bradford, and Palette offers type aliases in the
lms module to make using them a bit more convenient. It’s of
course also possible to simply use Lms::new, but it may not be as
intuitive.
use palette::{
lms::{Lms, VonKriesLms, matrix::VonKries},
white_point::D65,
Srgb, FromColor
};
let von_kries_lms = Lms::<VonKries, f32>::new(0.1, 0.2, 0.3);
let von_kries_d65_lms = VonKriesLms::<D65, f32>::new(0.1, 0.2, 0.3);
// `new` is also `const`:
const VON_KRIES_LMS: Lms<VonKries, f32> = Lms::new(0.1, 0.2, 0.3);
// Von Kries LMS from sRGB:
let lms_from_srgb = VonKriesLms::<D65, f32>::from_color(Srgb::new(0.3f32, 0.8, 0.1));
// It's also possible to convert from (and to) arrays and tuples:
let lms_from_array = VonKriesLms::<D65, f32>::from([0.1, 0.2, 0.3]);
let lms_from_tuple = VonKriesLms::<D65, f32>::from((0.1, 0.2, 0.3));Fields
long: TStimulus from long wavelengths, or red, or ρ. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.
medium: TStimulus from medium wavelengths, or green, or γ. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.
short: TStimulus from short wavelengths, or blue, or β. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.
meta: PhantomData<M>Type level meta information, such as reference white, or which matrix was used when converting from XYZ.
Implementations
Sourceimpl<M, T> Lms<M, T>
impl<M, T> Lms<M, T>
Sourcepub fn into_format<U>(self) -> Lms<M, U>where
U: FromStimulus<T>,
pub fn into_format<U>(self) -> Lms<M, U>where
U: FromStimulus<T>,
Convert the LMS components into another number type.
use palette::{
lms::VonKriesLms,
white_point::D65,
};
let lms_f64: VonKriesLms<D65, f64> = VonKriesLms::new(0.3f32, 0.7, 0.2).into_format();Sourcepub fn from_format<U>(color: Lms<M, U>) -> Lms<M, T>where
T: FromStimulus<U>,
pub fn from_format<U>(color: Lms<M, U>) -> Lms<M, T>where
T: FromStimulus<U>,
Convert the LMS components from another number type.
use palette::{
lms::VonKriesLms,
white_point::D65,
};
let lms_f64 = VonKriesLms::<D65, f64>::from_format(VonKriesLms::new(0.3f32, 0.7, 0.2));Sourcepub fn into_components(self) -> (T, T, T)
pub fn into_components(self) -> (T, T, T)
Convert to a (long, medium, short) tuple.
Sourcepub fn from_components(_: (T, T, T)) -> Lms<M, T>
pub fn from_components(_: (T, T, T)) -> Lms<M, T>
Convert from a (long, medium, short) tuple.
Sourcepub fn with_meta<NewM>(self) -> Lms<NewM, T>
pub fn with_meta<NewM>(self) -> Lms<NewM, T>
Changes the meta type without changing the color value.
This function doesn’t change the numerical values, and thus the stimuli it represents in an absolute sense. However, the appearance of the color may not be the same. The effect may be similar to taking a photo with an incorrect white balance.
Sourceimpl<M, T> Lms<M, T>
impl<M, T> Lms<M, T>
Sourcepub fn matrix_from_xyz() -> Matrix3<Xyz<<M as HasXyzMeta>::XyzMeta, T>, Lms<M, T>>
pub fn matrix_from_xyz() -> Matrix3<Xyz<<M as HasXyzMeta>::XyzMeta, T>, Lms<M, T>>
Sourceimpl<M, C> Lms<M, C>
impl<M, C> Lms<M, C>
Sourcepub fn iter<'a>(&'a self) -> <&'a Lms<M, C> as IntoIterator>::IntoIterwhere
&'a Lms<M, C>: IntoIterator,
pub fn iter<'a>(&'a self) -> <&'a Lms<M, C> as IntoIterator>::IntoIterwhere
&'a Lms<M, C>: IntoIterator,
Return an iterator over the colors in the wrapped collections.
Sourcepub fn iter_mut<'a>(
&'a mut self,
) -> <&'a mut Lms<M, C> as IntoIterator>::IntoIterwhere
&'a mut Lms<M, C>: IntoIterator,
pub fn iter_mut<'a>(
&'a mut self,
) -> <&'a mut Lms<M, C> as IntoIterator>::IntoIterwhere
&'a mut Lms<M, C>: IntoIterator,
Return an iterator that allows modifying the colors in the wrapped collections.
Sourcepub fn get<'a, I, T>(
&'a self,
index: I,
) -> Option<Lms<M, &'a <I as SliceIndex<[T]>>::Output>>
pub fn get<'a, I, T>( &'a self, index: I, ) -> Option<Lms<M, &'a <I as SliceIndex<[T]>>::Output>>
Get a color, or slice of colors, with references to the components at index. See slice::get for details.
Sourcepub fn get_mut<'a, I, T>(
&'a mut self,
index: I,
) -> Option<Lms<M, &'a mut <I as SliceIndex<[T]>>::Output>>
pub fn get_mut<'a, I, T>( &'a mut self, index: I, ) -> Option<Lms<M, &'a mut <I as SliceIndex<[T]>>::Output>>
Get a color, or slice of colors, that allows modifying the components at index. See slice::get_mut for details.
Sourceimpl<M, T> Lms<M, Vec<T>>
impl<M, T> Lms<M, Vec<T>>
Sourcepub fn with_capacity(capacity: usize) -> Lms<M, Vec<T>>
Available on crate feature alloc only.
pub fn with_capacity(capacity: usize) -> Lms<M, Vec<T>>
alloc only.Create a struct of vectors with a minimum capacity. See Vec::with_capacity for details.
Sourcepub fn push(&mut self, value: Lms<M, T>)
Available on crate feature alloc only.
pub fn push(&mut self, value: Lms<M, T>)
alloc only.Push an additional color’s components onto the component vectors. See Vec::push for details.
Sourcepub fn pop(&mut self) -> Option<Lms<M, T>>
Available on crate feature alloc only.
pub fn pop(&mut self) -> Option<Lms<M, T>>
alloc only.Pop a color’s components from the component vectors. See Vec::pop for details.
Sourcepub fn clear(&mut self)
Available on crate feature alloc only.
pub fn clear(&mut self)
alloc only.Clear the component vectors. See Vec::clear for details.