pub type VonKriesLms<M, T> = Lms<WithLmsMatrix<M, VonKries>, T>;Expand description
LMS that uses the von Kries matrix.
Aliased Type
#[repr(C)]pub struct VonKriesLms<M, T> {
pub long: T,
pub medium: T,
pub short: T,
pub meta: PhantomData<WithLmsMatrix<M, VonKries>>,
}Fields
long: TStimulus from long wavelengths, or red, or ρ. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.
medium: TStimulus from medium wavelengths, or green, or γ. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.
short: TStimulus from short wavelengths, or blue, or β. The typical range is between 0.0 and 1.0, but it doesn’t have an actual upper bound.
meta: PhantomData<WithLmsMatrix<M, VonKries>>Type level meta information, such as reference white, or which matrix was used when converting from XYZ.